! Multi-parallel support functions for PETot
! by Joshua Schrier (jschrier@lbl.gov), 16 June 02006 
! used, e.g., for FMO eval


!here's how it works:  we define an auxiliary MPI_COMM_WORLD (called
! "XMPI_COMM_WORLD" for each group of tasks.  Calls such as "abort"
! will terminate all the tasks (this seems appropriate), whereas
! tasks synchronizing data between variou nodes within a task will
! make reference either to XMPI_COMM_WORLD, or its subgroups
! MPI_COMM_K and MPI_COMM_N (notice that now _K and _N are subgroups
! that are split off of XMPI_COMM_WORLD).  The only remaining trick
! then is to change the input/output so that instead of using
! "etot.input" and "report"/stdout for inputs and outputs, that they
! label these with different integers. 


module MParallel

  integer :: GLOBAL_totalnodes, GLOBAL_rank
  integer :: XMPI_COMM_WORLD, XMPI_color, XMPI_key,jobstartID
  character (len=50) :: etotfile,stdoutfile,reportfile
  include 'mpif.h'
  implicit none

contains

  subroutine MP_initialize(nXMPI,nnodes_k,num_group,inode_tot,nnodes_tot, &
       icolor,ikey,nnodes,inode,MPI_COMM_K,MPI_COMM_N,XMPI_color)
    integer, intent(in) :: nXMPI,nnodes_k, num_group
    integer, intent(out) :: inode_tot,nnodes_tot,icolor,ikey,nnodes,inode
    integer, intent(out) :: MPI_COMM_K, MPI_COMM_N
    integer XMPI_color


    integer :: ierr

! allocate the XMPI sub-world

    call mpi_init(ierr)
    call mpi_comm_size(MPI_COMM_WORLD,GLOBAL_totalnodes,ierr)
    call mpi_comm_rank(MPI_COMM_WORLD,GLOBAL_rank,ierr)

!    if (GLOBAL_rank .eq. 0) then 
!       write (6,*) "nXMPI, nnodes_k,num_group = ", nXMPI, nnodes_k,num_group
!    end if

    if (nXMPI*nnodes_k*num_group .ne. GLOBAL_totalnodes) then
       write(6,*) "nXMPI*num_group*nnodes_k .ne. GLOBAL_totalnodes, stop"
       call mpi_abort(MPI_COMM_WORLD)
    end if

    XMPI_color = mod(GLOBAL_RANK,nXMPI)
    XMPI_key = int(GLOBAL_RANK/nXMPI)
    
!    write (6,*) 'XMPI_color, XMPI_key, global_rank, global_totalnodes = ', &
!         XMPI_color, XMPI_key, GLOBAL_rank, GLOBAL_totalnodes

    call mpi_comm_split(MPI_COMM_WORLD,XMPI_color,XMPI_key,  &
         XMPI_COMM_WORLD,ierr)

  
!
! for each XMPI sub-world, initialize  MPI_COMM_K and MPI_COMM_N
!

! split the processors into num_group groups, with MPI_COMM_K as
! their group communicator and ikey as the local inode
! (essentially, just generalize the way LW does this in the original code)

    call mpi_comm_rank(XMPI_COMM_WORLD,inode_tot,ierr)
    call mpi_comm_size(XMPI_COMM_WORLD,nnodes_tot,ierr)
    
! Steven Chu says: "Safety first."  Perform a sanity check to
! make sure that the XMPI subgroup has the correct number of nodes
  
    if(nnodes_k*num_group.ne.nnodes_tot) then
       write(6,*) "nnodes_k*num_group.ne.nnodes_tot,stop", &
            nnodes_k,num_group,nnodes_tot
       call mpi_abort(MPI_COMM_WORLD)
    endif
    
    icolor=inode_tot/nnodes_k
    ikey=inode_tot-icolor*nnodes_k
    
    call mpi_comm_split(XMPI_COMM_WORLD,icolor,ikey,MPI_COMM_K,ierr)
    inode_tot=inode_tot+1
    nnodes=nnodes_k
    inode=ikey+1
    
    call mpi_comm_split(XMPI_COMM_WORLD,ikey,icolor,MPI_COMM_N,ierr)

  end subroutine MP_initialize
  

!  subroutine MP_assignFilenames(id)
!    integer, intent(in) :: id
!
!    write(etotfile,"('etot.input.',i3.3)") id
!    write(stdoutfile,"('stdout.',i3.3)") id
!    write(reportfile,"('report.',i3.3)") id
!
!
!  end subroutine MP_assignFilenames

  subroutine MP_assignFilenames(work_dir,id)
    integer, intent(in) :: id
    character*(*),intent(in)::work_dir
                                                                                                                     
    write(etotfile,"('etot.input.',i3.3)") id
    etotfile=trim(work_dir)//'/'//etotfile
    write(stdoutfile,"('stdout.',i3.3)") id
    stdoutfile=trim(work_dir)//'/'//stdoutfile
    write(reportfile,"('report.',i3.3)") id
    reportfile=trim(work_dir)//'/'//reportfile
!    write(6,*) etotfile,stdoutfile,reportfile
                                                                                                                     
                                                                                                                     
  end subroutine MP_assignFilenames
  

 subroutine MP_assignFilenames1(work_dir,fm_label)
    character*(*),intent(in)::work_dir
    character*(*),intent(in)::fm_label
                                      
    etotfile=trim(work_dir)//'/'//'etot.input_'//fm_label
    stdoutfile=trim(work_dir)//'/'//'stdout_'//fm_label
    reportfile=trim(work_dir)//'/'//'report_'//fm_label
  end subroutine MP_assignFilenames1
end module MParallel
